+++
title = "Conclusion"
description = "Summary, conclusion and next steps"
date = "2019-08-07"
author = "Christian Decker"
sec = 7
+++

This section concludes the project.

### Summary

The list below displays the achieved objectives:

* [x] To be able to setup a Raspi from scratch
* [x] To be able to develop a simple command line software
* [x] To enable a software to automatically restart after shutdown / power off
* [ ] To enable resilience by monitoring and restarting software processes remotely

### Conclusion

I successfully acquired new development skills for raspi computers. They provide a valuable contribution to my CV.

### Next Steps

There are other embedded systems. Will approach them as my next programming plattform. 




